mailadm tool (beta)
======================

mailadm is the reference administration tool for managing
e-mail accounts at https://testrun.org which uses a
standard dovecot/postfix installation.

On a debian system it allows to run a https-exposed
e-mail account creation service as a wsgi server app
that you can run via systemd (see mailadm.service example).

See the `docs/index.rst` file or https://mailadm.readthedocs.io for more info.
